@@ -1,4 +1,5 @@
 import re
+from loguru import logger
 
 
 class Name_That_Hash:
@@ -10,8 +11,11 @@ class Name_That_Hash:
         self.prototypes = list(prototypes)
 
     def identify(self, chash: str):
+        logger.trace(chash)
         chash = chash.strip()
+        output = []
         for prototype in self.prototypes:
             if prototype.regex.match(chash):
                 for mode in prototype.modes:
-                    yield mode
+                    output.append(mode)
+        return output
